package com.atguigu.handler;


import com.atguigu.constant.MessageConstant;
import com.atguigu.exception.BunnyException;
import com.atguigu.spzx.model.vo.result.Result;
import com.atguigu.spzx.model.vo.result.ResultCodeEnum;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import java.nio.file.AccessDeniedException;
import java.sql.SQLIntegrityConstraintViolationException;

@RestControllerAdvice
@Slf4j
public class GlobalExceptionHandler {
    // 自定义异常信息
    @ExceptionHandler(BunnyException.class)
    @ResponseBody
    public Result<Object> exceptionHandler(BunnyException exception) {
        log.error("自定义异常信息：{}", exception.getMessage());
        return Result.error(exception.getCode(), exception.getMessage());
    }

    // 运行时异常信息
    @ExceptionHandler(RuntimeException.class)
    @ResponseBody
    public Result<Object> exceptionHandler(RuntimeException exception) {
        log.error("运行时异常信息：{}", exception.getMessage());
        return Result.error(500, exception.getMessage());
    }

    // 捕获系统异常
    @ExceptionHandler(Exception.class)
    @ResponseBody
    public Result<Object> error(Exception exception) {
        log.error("系统异常信息：{}", exception.getMessage());
        return Result.error(exception.getMessage());
    }

    // 特定异常处理
    @ExceptionHandler(ArithmeticException.class)
    @ResponseBody
    public Result<Object> error(ArithmeticException exception) {
        log.error("特定异常信息：{}", exception.getMessage());
        return Result.error(null, exception.getMessage());
    }

    // spring security异常
    @ExceptionHandler(AccessDeniedException.class)
    @ResponseBody
    public Result<String> error(AccessDeniedException e) throws AccessDeniedException {
        return Result.error(ResultCodeEnum.PERMISSION);
    }

    // 处理SQL异常
    @ExceptionHandler(SQLIntegrityConstraintViolationException.class)
    @ResponseBody
    public Result<String> exceptionHandler(SQLIntegrityConstraintViolationException exception) {
        log.error("处理SQL异常:{}", exception.getMessage());
        String message = exception.getMessage();
        if (message.contains("Duplicate entry")) {
            // 截取用户名
            String username = message.split(" ")[2];
            // 错误信息
            String errorMessage = username + MessageConstant.ALREADY_EXISTS;
            return Result.error(exception.getMessage());
        } else {
            return Result.error(MessageConstant.UNKNOWN_ERROR);
        }
    }
}
