package com.atguigu.spzx.manger.service.impl;

import cn.hutool.captcha.CaptchaUtil;
import cn.hutool.captcha.CircleCaptcha;
import com.atguigu.spzx.manger.service.ValidateCodeService;
import com.atguigu.spzx.model.vo.system.ValidateCodeVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Service
public class ValidateCodeServiceImpl implements ValidateCodeService {
    @Autowired
    private RedisTemplate redisTemplate;

    /**
     * 生成验证码信息
     *
     * @return 验证码响应结果实体类
     */
    @Override
    public ValidateCodeVo generateValidateCode() {
        // 1. 通过工具生成验证码
        CircleCaptcha captcha = CaptchaUtil.createCircleCaptcha(150, 48, 4, 2);
        String code = captcha.getCode();
        String base64Image = "data:image/png;base64," + captcha.getImageBase64();
        // 2. 验证码存储到Redis中，Redis的key为UUID，值为验证码的值
        String key = UUID.randomUUID().toString();
        // 3. 返回ValidateCodeVo
        redisTemplate.opsForValue().set(key, code, 1, TimeUnit.MINUTES);
        return ValidateCodeVo.builder().codeKey(key).codeValue(base64Image).build();
    }
}
